@@ -10,7 +10,9 @@ a probability density function for the principal stress components.
 
 __author__ = """Jeff Burghardt"""
 __email__ = 'jeffrey.burghardt@pnnl.gov'
-__version__ = '0.1.0'
+__version__ = '0.2.4'
 
 from .stress_state import StressState
 from .constraints import FaultConstraint
+from .constraints import FaultingRegimeConstraint, SU
+from .constraints import BreakoutConstraint
